#ifndef __SYSTEM_INCLUDED__
#define	__SYSTEM_INCLUDED__

/*
	=================================
	Define Data Types on Local System
	=================================
*/

#define	SBYTE	signed char
#define	SWORD	signed short int
#define	SLONG	signed long int
#define	UBYTE	unsigned char
#define	UWORD	unsigned short int
#define	ULONG	unsigned long int

#define	CURSES_LEFT	0x00
#define	CURSES_CENTRAL	0x01
#define	CURSES_RIGHT	0x02
#define	CURSES_WIDE_1	0x03
#define	CURSES_WIDE_2	0x04

typedef enum
{
	Atari,
	AtariXL,
	AtariXE
} Machine;

extern Machine	machine;

#endif
